@@ -1,7 +1,7 @@
 __project_name__ = 'upsies'
 __description__ = 'Media metadata aggregator'
 __homepage__ = 'https://upsies.readthedocs.io'
-__version__ = '2021.10.04'
+__version__ = '2021.10.23'
 __author__ = 'plotski'
 __author_email__ = 'plotski@example.org'
 
@@ -12,9 +12,14 @@ def application_setup(config):
 
     :param config: :class:`~.configfiles.ConfigFiles` instance
     """
+    import os
+
     from . import utils
 
-    utils.http.cache_directory = config['config']['main']['cache_directory']
+    utils.http.cache_directory = os.path.join(
+        config['config']['main']['cache_directory'],
+        'http',
+    )
 
 
 def application_shutdown(config):
@@ -32,4 +37,4 @@ def application_shutdown(config):
         max_total_size=config['config']['main']['max_cache_size'],
     )
 
-    asyncio.get_event_loop().run_until_complete(utils.http.close())
+    utils.get_aioloop().run_until_complete(utils.http.close())
