@@ -378,13 +378,12 @@ class JobBase(abc.ABC):
 
         :param Exception exception: Exception instance
         """
-        if not self.is_finished:
-            import traceback
-            tb = ''.join(traceback.format_exception(
-                type(exception), exception, exception.__traceback__))
-            _log.debug('Exception in %s: %s', self.name, tb)
-            self._exception = exception
-            self.finish()
+        import traceback
+        tb = ''.join(traceback.format_exception(
+            type(exception), exception, exception.__traceback__))
+        _log.debug('Exception in %s: %s', self.name, tb)
+        self._exception = exception
+        self.finish()
 
     @property
     def raised(self):
@@ -623,6 +622,9 @@ class QueueJobBase(JobBase):
             else:
                 try:
                     await self.handle_input(value)
+                except asyncio.CancelledError:
+                    _log.debug('%s: Job was cancelled while handling %r', self.name, value)
+                    break
                 except BaseException as e:
                     self.exception(e)
                     break
