@@ -7,7 +7,7 @@ import collections
 from time import monotonic as time_monotonic
 
 from .. import errors
-from ..utils import webdbs
+from ..utils import get_aioloop, webdbs
 from . import JobBase
 
 import logging  # isort:skip
@@ -239,7 +239,7 @@ class _Searcher:
         if self._search_task:
             self._search_task.cancel()
             self._search_task = None
-        self._search_task = asyncio.ensure_future(self._search(query))
+        self._search_task = get_aioloop().create_task(self._search(query))
         self._search_task.add_done_callback(self._handle_search_task)
 
     async def _search(self, query):
