@@ -47,6 +47,7 @@ class BbTracker(TrackerBase):
             )
 
             doc = html.parse('')
+            _log.debug('LOGINBUGDEBUG: Initial doc: %r', doc)
             while await self._work_around_login_bug(doc):
                 _log.debug('%s: Logging in as %r', self.name, self.options['username'])
                 response = await http.post(
@@ -58,7 +59,9 @@ class BbTracker(TrackerBase):
                         'login': 'Log In!',
                     },
                 )
+                _log.debug('LOGINBUGDEBUG: Login response: %r', response)
                 doc = html.parse(response)
+                _log.debug('LOGINBUGDEBUG: New doc %r', doc)
                 self._raise_login_error(doc)
 
             self._store_auth_token(doc)
@@ -97,13 +100,24 @@ class BbTracker(TrackerBase):
 
     @classmethod
     def _get_auth_token(cls, doc):
-        auth_tag = doc.find('a', href=cls._auth_token_regex)
-        if auth_tag:
-            auth_link = auth_tag['href']
-            if auth_link:
-                match = cls._auth_token_regex.search(auth_link)
+        logout_link_tag = doc.find('a', href=cls._auth_token_regex)
+        if logout_link_tag:
+            _log.debug('LOGINBUGDEBUG: logout_link_tag: %r', logout_link_tag)
+            logout_link_href = logout_link_tag['href']
+            _log.debug('LOGINBUGDEBUG: logout_link_href: %r', logout_link_href)
+            if logout_link_href:
+                match = cls._auth_token_regex.search(logout_link_href)
+                _log.debug('LOGINBUGDEBUG: logout_link_href match: %r', match)
                 if match:
+                    _log.debug('LOGINBUGDEBUG: auth_token: %r', match.group(1))
                     return match.group(1)
+                else:
+                    _log.debug('LOGINBUGDEBUG: Failed to find auth token: %r does not match %r',
+                               logout_link_href, cls._auth_token_regex)
+            else:
+                _log.debug('LOGINBUGDEBUG: Failed to find logout URL in HTML: %r', logout_link_tag)
+        else:
+            _log.debug('LOGINBUGDEBUG: Failed to find logout link tag in HTML: %r', doc)
 
     def _store_auth_token(self, doc):
         auth_token = self._get_auth_token(doc)
@@ -111,7 +125,6 @@ class BbTracker(TrackerBase):
             raise RuntimeError('Failed to find authentication token')
         else:
             self._auth_token = auth_token
-            _log.debug('%s: Authentication token: %s', self.name, self._auth_token)
 
     @property
     def is_logged_in(self):
@@ -138,10 +151,9 @@ class BbTracker(TrackerBase):
         doc = html.parse(response)
         announce_url_tag = doc.find('input', value=re.compile(r'^https?://.*/announce$'))
         if announce_url_tag:
-            _log.debug('%s: Announce URL: %s', self.name, announce_url_tag['value'])
             return announce_url_tag['value']
         else:
-            _log.debug('%s: Failed to find announce URL in %s', self.name, doc.prettify())
+            _log.debug('%s: Failed to find announce URL', self.name)
 
     async def upload(self, tracker_jobs):
         _log.debug('Uploading %r', tracker_jobs.post_data)
@@ -150,7 +162,7 @@ class BbTracker(TrackerBase):
             url=upload_url,
             cache=False,
             user_agent=True,
-            allow_redirects=False,
+            follow_redirects=False,
             files={'file_input': {
                 'file': tracker_jobs.torrent_filepath,
                 'mimetype': 'application/octet-stream',
