@@ -12,7 +12,7 @@ import textwrap
 
 from .... import (__description__, __project_name__, __version__, constants,
                   defaults, errors, utils)
-from ....utils import configfiles
+from .. import utils as tuiutils
 
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
@@ -49,8 +49,11 @@ class _MyHelpFormatter(argparse.HelpFormatter):
                     subsequent_indent=indent,
                 )
 
-        width = min(width, self.MAX_WIDTH) - len(indent)
-        text = re.sub(r'``(.*?)``', '\x1b[3m\\1\x1b[23m', text)
+        if tuiutils.is_tty():
+            text = re.sub(r'``(.*?)``', '\x1b[3m\\1\x1b[23m', text)
+        else:
+            text = re.sub(r'``(.*?)``', r'"\1"', text)
+
         return [line
                 for paragraph in text.split('\n')
                 for line in wrap(paragraph)]
@@ -148,12 +151,18 @@ class CommandBase(abc.ABC):
 
         This classmethod must be called on every subclass.
         """
+        # Get long text in output of "upsies <subcommand> --help"
         if cls.description:
             description = textwrap.dedent(cls.__doc__.strip('\n')) + '\n\n' + cls.description
         else:
             description = textwrap.dedent(cls.__doc__.strip('\n'))
 
+        if cls.subcommands:
+            description += f'\n\nRun ``upsies {cls.names[0]} {cls.subcommand_name} --help`` for more information.'
+
+        # Get short text in output of "upsies --help"
         help = description.split('\n', 1)[0]
+
         parser = cls._subparsers.add_parser(
             cls.names[0],
             aliases=cls.names[1:],
@@ -240,7 +249,7 @@ class CommandBase(abc.ABC):
 
         # Read config files
         try:
-            config = configfiles.ConfigFiles(defaults=defaults.defaults)
+            config = utils.configfiles.ConfigFiles(defaults=defaults.defaults)
             config.read('config', filepath=main_args.config_file, ignore_missing=True)
             config.read('trackers', filepath=main_args.trackers_file, ignore_missing=True)
             config.read('imghosts', filepath=main_args.imghosts_file, ignore_missing=True)
