@@ -2,7 +2,6 @@
 Interactive text user interface and job manager
 """
 
-import asyncio
 import collections
 import types
 
@@ -11,6 +10,7 @@ from prompt_toolkit.key_binding import KeyBindings
 from prompt_toolkit.layout import Layout
 from prompt_toolkit.layout.containers import HSplit, Window, to_container
 
+from ... import utils
 from . import jobwidgets, style
 
 import logging  # isort:skip
@@ -27,8 +27,7 @@ class TUI:
         self._app = self._make_app()
         self._app_terminated = False
         self._exception = None
-        self._loop = asyncio.get_event_loop()
-        self._loop.set_exception_handler(self._handle_exception)
+        utils.get_aioloop().set_exception_handler(self._handle_exception)
 
     def _handle_exception(self, loop, context):
         exception = context.get('exception')
@@ -67,6 +66,7 @@ class TUI:
             full_screen=False,
             erase_when_done=False,
             mouse_support=False,
+            on_invalidate=self._update_jobs_container,
         )
         # Make escape key work
         app.timeoutlen = 0.1
@@ -98,7 +98,7 @@ class TUI:
     def _update_jobs_container(self, *_):
         job_containers = []
 
-        # Ensure enabled jobs are started
+        # Start all enabled jobs that are supposed to start automatically
         for jobinfo in self._enabled_jobs:
             if not jobinfo.job.is_started and jobinfo.job.autostart:
                 jobinfo.job.start()
@@ -107,13 +107,16 @@ class TUI:
         for jobinfo in self._enabled_jobs:
             if jobinfo.widget.is_interactive:
                 job_containers.append(jobinfo.container)
+
                 # Focus the first unfinished job
                 if not jobinfo.job.is_finished:
-                    _log.debug('Active job: %r', jobinfo.job.name)
                     try:
                         self._layout.focus(jobinfo.container)
                     except ValueError:
-                        pass
+                        _log.debug('Failed to focus job: %r', jobinfo.job.name)
+                    else:
+                        _log.debug('Focused job: %r', jobinfo.job.name)
+
                     # Don't display more than one unfinished interactive job
                     # unless any job has errors, in which case we are
                     # terminating the application and display all jobs.
@@ -176,7 +179,7 @@ class TUI:
     def _exit(self):
         if not self._app_terminated:
             if not self._app.is_running and not self._app.is_done:
-                self._loop.call_soon(self._exit)
+                utils.get_aioloop().call_soon(self._exit)
             else:
                 def handle_jobs_terminated(task):
                     try:
