@@ -2,6 +2,7 @@
 Swiss Army knife
 """
 
+import asyncio
 import collections
 import importlib
 import inspect
@@ -11,6 +12,22 @@ import sys
 import types as _types
 
 
+def get_aioloop():
+    """Return :class:`asyncio.AbstractEventLoop` instance"""
+    # https://docs.python.org/3.10/library/asyncio-eventloop.html
+    try:
+        return asyncio.get_running_loop()
+    # "no running event loop"
+    except RuntimeError:
+        # We need a loop before the application has started.
+        # This mimics get_event_loop(), but that is going to be an alias for
+        # get_running_loop() in future Python releases.
+        return asyncio.get_event_loop_policy().get_event_loop()
+    except AttributeError:
+        # Python 3.6 doesn't have get_running_loop()
+        return asyncio.get_event_loop()
+
+
 def os_family():
     """
     Return "windows" or "unix"
